Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(392)

Unified Diff: components/offline_pages/snapshot_controller.h

Issue 2063533002: Rewrite enum in MACRO_STYLE (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 4 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/offline_pages/snapshot_controller.h
diff --git a/components/offline_pages/snapshot_controller.h b/components/offline_pages/snapshot_controller.h
index 00a2edf7ff8a2dd526dccd52feadd780487edaa6..3e07cce2e5128efb46526f256034cfcd86aaf7c3 100644
--- a/components/offline_pages/snapshot_controller.h
+++ b/components/offline_pages/snapshot_controller.h
@@ -25,10 +25,14 @@ namespace offline_pages {
// reset so no StartSnapshot calls is made 'cross-session'.
class SnapshotController {
public:
- // kStateReady - listening to input, will start snapshot when needed.
- // kStateSnapshotPending - snapshot is in progress, don't start another.
- // kStateStopped - terminal state, no snapshots until reset.
- enum class State { kReady, kSnapshotPending, kStopped };
+ // READY - listening to input, will start snapshot when needed.
+ // SNAPSHOT_PENDING- snapshot is in progress, don't start another.
+ // STOPPED - terminal state, no snapshots until reset.
+ enum class State {
+ READY,
fgorski 2016/06/11 16:25:06 Put documentation after the definition of the enum
Vivian 2016/06/13 17:07:04 Done.
+ SNAPSHOT_PENDING,
+ STOPPED,
+ };
// Client of the SnapshotController.
class Client {

Powered by Google App Engine
This is Rietveld 408576698